@@ -64,9 +64,15 @@ _OPTIONS = [
         The template used by reno new to create a note.
         """)),
 
+    Opt('add_release_date', False,
+        textwrap.dedent("""\
+        Should the report include release date (True) based on
+        the date of objects associated with the release tag.
+        """)),
+
     Opt('release_tag_re',
         textwrap.dedent('''\
-        ((?:v?[\d.ab]|rc)+)  # digits, a, b, and rc cover regular and
+        ((?:v?[\\d.ab]|rc)+)  # digits, a, b, and rc cover regular and
                            # pre-releases
         '''),
         textwrap.dedent("""\
@@ -77,7 +83,7 @@ _OPTIONS = [
 
     Opt('pre_release_tag_re',
         textwrap.dedent('''\
-        (?P<pre_release>\.v?\d+(?:[ab]|rc)+\d*)$
+        (?P<pre_release>\\.v?\\d+(?:[ab]|rc)+\\d*)$
         '''),
         textwrap.dedent("""\
         The regex pattern used to check if a valid release version tag
@@ -218,7 +224,7 @@ class Config(object):
             if os.path.isfile(filename):
                 break
         else:
-            LOG.info('no configuration file in: %s', ', '.join(filenames))
+            self._report_missing_config_files(filenames)
             return
 
         try:
@@ -226,9 +232,20 @@ class Config(object):
                 self._contents = yaml.safe_load(fd)
             LOG.info('loaded configuration file %s', filename)
         except IOError as err:
-            LOG.warning('did not load config file %s: %s', filename, err)
+            self._report_failure_config_file(filename, err)
         else:
-            self.override(**self._contents)
+            if self._contents:
+                self.override(**self._contents)
+
+    def _report_missing_config_files(self, filenames):
+        # NOTE(dhellmann): This is extracted so we can mock it for
+        # testing.
+        LOG.info('no configuration file in: %s', ', '.join(filenames))
+
+    def _report_failure_config_file(self, filename, err):
+        # NOTE(dhellmann): This is extracted so we can mock it for
+        # testing.
+        LOG.warning('did not load config file %s: %s', filename, err)
 
     def _rename_prelude_section(self, **kwargs):
         key = 'prelude_section_name'
@@ -265,9 +282,11 @@ class Config(object):
         arg_values = {
             o.name: getattr(parsed_args, o.name)
             for o in _OPTIONS
-            if hasattr(parsed_args, o.name)
+            if getattr(parsed_args, o.name, None) is not None
         }
-        self.override(**arg_values)
+        if arg_values:
+            LOG.info('[config] updating from command line options')
+            self.override(**arg_values)
 
     @property
     def reporoot(self):
