@@ -10,35 +10,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import print_function
-
 import os
+import subprocess
 
 from reno import utils
 
 
-_TEMPLATE = """\
----
-prelude: >
-    Replace this text with content to appear at the
-    top of the section for this release.
-features:
-  - List new features here, or remove this section.
-issues:
-  - List known issues here, or remove this section.
-upgrade:
-  - List upgrade notes here, or remove this section.
-critical:
-  - Add critical notes here, or remove this section.
-security:
-  - Add security notes here, or remove this section.
-fixes:
-  - Add normal bug fixes here, or remove this section.
-other:
-  - Add other notes here, or remove this section.
-"""
-
-
 def _pick_note_file_name(notesdir, slug):
     "Pick a unique name in notesdir."
     for i in range(50):
@@ -53,17 +30,33 @@ def _pick_note_file_name(notesdir, slug):
         )
 
 
-def _make_note_file(filename):
+def _make_note_file(filename, template):
     notesdir = os.path.dirname(filename)
     if not os.path.exists(notesdir):
         os.makedirs(notesdir)
     with open(filename, 'w') as f:
-        f.write(_TEMPLATE)
+        f.write(template)
 
 
-def create_cmd(args):
+def _edit_file(filename):
+    if 'EDITOR' not in os.environ:
+        return False
+    subprocess.call([os.environ['EDITOR'], filename])
+    return True
+
+
+def _get_user_template(template_file):
+    if not os.path.exists(template_file):
+        raise ValueError(
+            'The provided template file %s doesn\'t '
+            'exist' % template_file,
+        )
+    with open(template_file, 'r') as f:
+        return f.read()
+
+
+def create_cmd(args, conf):
     "Create a new release note file from the template."
-    notesdir = utils.get_notes_dir(args)
     # NOTE(dhellmann): There is a short race window where we might try
     # to pick a name that does not exist, then overwrite the file if
     # it is created before we try to write it. This isn't a problem
@@ -71,7 +64,14 @@ def create_cmd(args):
     # their local git tree, and so there should not be any concurrency
     # concern.
     slug = args.slug.replace(' ', '-')
-    filename = _pick_note_file_name(notesdir, slug)
-    _make_note_file(filename)
+    filename = _pick_note_file_name(conf.notespath, slug)
+    if args.from_template:
+        template = _get_user_template(args.from_template)
+    else:
+        template = conf.template
+    _make_note_file(filename, template)
+    if args.edit and not _edit_file(filename):
+        print('Was unable to edit the new note. EDITOR environment variable '
+              'is missing!')
     print('Created new notes file in %s' % filename)
     return
