@@ -10,8 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import print_function
-
 from reno import formatter
 from reno import loader
 
@@ -27,7 +25,9 @@ def report_cmd(args, conf):
         ldr,
         conf,
         versions,
-        title='Release Notes',
+        title=args.title,
+        show_source=args.show_source,
+        branch=args.branch,
     )
     if args.output:
         with open(args.output, 'w') as f:
