@@ -10,8 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import print_function
-
 import collections
 import fnmatch
 import logging
@@ -391,6 +389,7 @@ class RenoRepo(repo.Repo):
     # Populated by _load_tags().
     _all_tags = None
     _shas_to_tags = None
+    _tags_to_dates = None
 
     def _get_commit_from_tag(self, tag, tag_sha):
         """Return the commit referenced by the tag and when it was tagged."""
@@ -434,9 +433,11 @@ class RenoRepo(repo.Repo):
             if k.startswith(b'refs/tags/')
         }
         self._shas_to_tags = {}
+        self._tags_to_dates = {}
         for tag, tag_sha in self._all_tags.items():
             tagged_sha, date = self._get_commit_from_tag(tag, tag_sha)
             self._shas_to_tags.setdefault(tagged_sha, []).append((tag, date))
+            self._tags_to_dates[tag] = date
 
     def get_tags_on_commit(self, sha):
         "Return the tag(s) on a commit, in application order."
@@ -659,13 +660,13 @@ class Scanner(object):
                     c.commit.sha().hexdigest().encode('ascii'))
                 if tags:
                     return tags[-1]
-                else:
-                    # Naughty, naughty, branching without tagging.
-                    LOG.info(
-                        ('There is no tag on commit %s at the base of %s. '
-                         'Branch scan short-cutting is disabled.'),
-                        c.commit.sha().hexdigest(), branch)
-                    return None
+
+        # Naughty, naughty, branching without tagging.
+        LOG.info(
+            'There is no tag on commit %s at the base of %s. '
+            'Branch scan short-cutting is disabled.',
+            c.commit.sha().hexdigest(), branch,
+        )
         return None
 
     def _topo_traversal(self, branch):
@@ -759,8 +760,8 @@ class Scanner(object):
                     # later, as long as we haven't already processed
                     # it.
                     first_parent = entry.commit.parents[0]
-                    if (first_parent not in todo and
-                            first_parent not in emitted):
+                    if (first_parent not in todo
+                            and first_parent not in emitted):
                         todo.appendleft(first_parent)
                     continue
 
@@ -917,6 +918,12 @@ class Scanner(object):
                 return candidate
         return None
 
+    def get_version_dates(self):
+        "Return a dict mapping versions to dates."
+        if self._repo._tags_to_dates is not None:
+            return self._repo._tags_to_dates.copy()
+        return {}
+
     def get_notes_by_version(self, branch=None):
         """Return an OrderedDict mapping versions to lists of notes files.
 
