@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import unicode_literals
-
 import itertools
 import logging
 import os.path
@@ -21,11 +19,11 @@ import re
 import subprocess
 import time
 import unittest
+from unittest import mock
 
 from dulwich import diff_tree
 from dulwich import objects
 import fixtures
-import mock
 from testtools.content import text_content
 
 from reno import config
@@ -68,7 +66,7 @@ class GPGKeyFixture(fixtures.Fixture):
     def setUp(self):
         super(GPGKeyFixture, self).setUp()
         tempdir = self.useFixture(fixtures.TempDir())
-        gnupg_version_re = re.compile('^gpg\s.*\s([\d+])\.([\d+])\.([\d+])')
+        gnupg_version_re = re.compile(r'^gpg\s.*\s([\d+])\.([\d+])\.([\d+])')
         gnupg_version = utils.check_output(['gpg', '--version'],
                                            cwd=tempdir.path)
         for line in gnupg_version.split('\n'):
@@ -1271,10 +1269,19 @@ class BranchBaseTest(Base):
         self.repo.git('tag', '-d', '2.0.0')
         self._add_notes_file('slug4')
         self.repo.git('checkout', 'master')
-        self.assertIsNone(
-            self.scanner._get_branch_base('not-master')
+        self.assertEqual(
+            '1.0.0',
+            self.scanner._get_branch_base('not-master'),
         )
 
+    def test_no_tags(self):
+        # remove all tags from before the branch
+        self.repo.git('tag', '-d', '2.0.0')
+        self.repo.git('tag', '-d', '1.0.0')
+        self._add_notes_file('slug4')
+        self.repo.git('checkout', 'master')
+        self.assertIsNone(self.scanner._get_branch_base('not-master'))
+
 
 class BranchTest(Base):
 
